summaryrefslogtreecommitdiffstats
path: root/lib/private/avatar.php
diff options
context:
space:
mode:
authorJoas Schilling <nickvergessen@owncloud.com>2015-03-13 10:10:11 +0100
committerJoas Schilling <nickvergessen@owncloud.com>2015-03-16 12:45:15 +0100
commit8ed27d2ce0477f40a27cdc335361b0d5654a7e09 (patch)
treede2db82b384ab3071c2c17b8e84dd560b9df993c /lib/private/avatar.php
parent3b7aec1b7d4e2e3a1ff6c1f7888189c67aa09b75 (diff)
downloadnextcloud-server-8ed27d2ce0477f40a27cdc335361b0d5654a7e09.tar.gz
nextcloud-server-8ed27d2ce0477f40a27cdc335361b0d5654a7e09.zip
Create an interface for OC_Image and OCP\Image for the public API
Diffstat (limited to 'lib/private/avatar.php')
-rw-r--r--lib/private/avatar.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/private/avatar.php b/lib/private/avatar.php
index 23b3c82771a..da9c84d84a4 100644
--- a/lib/private/avatar.php
+++ b/lib/private/avatar.php
@@ -29,7 +29,7 @@ class Avatar implements \OCP\IAvatar {
/**
* get the users avatar
* @param int $size size in px of the avatar, avatars are square, defaults to 64
* @return boolean|\OC_Image containing the avatar or false if there's no image
*/
public function get ($size = 64) {
if ($this->view->file_exists('avatar.jpg')) {
@@ -57,14 +57,14 @@ class Avatar implements \OCP\IAvatar {
/**
* sets the users avatar
* @param \OC_Image|resource|string $data OC_Image, imagedata or path to set a new avatar
* @throws \Exception if the provided file is not a jpg or png image
* @throws \Exception if the provided image is not valid
* @throws \OC\NotSquareException if the image is not square
* @return void
*/
public function set ($data) {
- if($data instanceOf OC_Image) {
+ if($data instanceOf \OCP\IImage) {
$img = $data;
$data = $img->data();
} else {
@@ -29,7 +29,7 @@ class Avatar implements \OCP\IAvatar {
* get the users avatar
* @param int $size size in px of the avatar, avatars are square, defaults to 64
- * @return boolean|\OC_Image containing the avatar or false if there's no image
+ * @return boolean|\OCP\IImage containing the avatar or false if there's no image
*/
public function get ($size = 64) {
@@ -57,14 +57,14 @@ class Avatar implements \OCP\IAvatar {
/**
* sets the users avatar
- * @param \OC_Image|resource|string $data OC_Image, imagedata or path to set a new avatar
+ * @param \OCP\IImage|resource|string $data An image object, imagedata or path to set a new avatar
* @throws \Exception if the provided file is not a jpg or png image
* @throws \Exception if the provided image is not valid